# This Ren'py script is intended for testing for the visual novel project
# described here: http://larsmartinson.com/vn-design-doc
# That url contains a lot of info not covered here, so check it out.

# The design doc also defines attributes about the images included in the zip file,
# such as their [headAnchor] values and their [showFace] booleans and nonsense like that.

# I haven't made many crucial changes mentioned in the design doc (like changing fonts and so forth).
# I didn't want to make too many changes in case I messed things up more than helped. So I haven't made 
# *any* changes to the default options.rpy, gui.rpy, or screens.rpy, which is why I haven't included 
# them in the zip file.

# Note: Feel free to change *ANYTHING* that I've done here, or scrap it completely.
# I don't really know how to use Ren'py, so I'm sure there are much better ways to
# do things then I've done here. Most of this is sort of hacked together to get a
# rough sense of how it might work.



# Definitions for the two test characters:
define o = Character("Odette")
define d = Character("Dad")


# The following nine definitions are all related to color. I've provisionally set 
# [contextualBlack] and [accentColor] to the values below, but would like to be able 
# to change them dynamically as described in the design doc.
define contextualBlack = Color((78,53,39))
define accentColor = Color((176,151,112))
define accentColorWhite = Color(accentColor).tint(.2)
define colorizeBlack = im.matrix.colorize(contextualBlack, accentColor)
define colorizeStagePropLines = im.matrix.colorize(Color(contextualBlack).tint(.76), accentColorWhite)
define colorizePropGrey = im.matrix.colorize(accentColor, Color(accentColor).tint(0.25))
define colorizeStageGrey = im.matrix.colorize(contextualBlack, Color(accentColor).tint(0.4))
define colorizeOdetteGrey = im.matrix.colorize(Color(Color(accentColor).interpolate((255,130,130), 0.13)).tint(0.9), accentColorWhite)
define colorizeDadGrey = im.matrix.colorize(Color(Color(accentColor).interpolate((130,130,255), 0.13)).tint(0.9), accentColorWhite)


# This is for the [contextualBlack] bar that always exists at the bottom of the screen. I'm assuming
# there's a better way to implement this, just want to insert something to see how it looked.
image bottombar = Image(im.MatrixColor("uiimages/bg_black.png", colorizeBlack))



# The following declarations for the included sample [charaBody]s, starting with the Odette character for the first three,
# and the Dad character for the last one: 
image od_sittingWithHead = LiveComposite(
    (199, 511),
    (0, 0), Image (im.MatrixColor("chara/odette/charabody/b_od_sittinghead_colors.png", colorizeOdetteGrey)),
    (0, 0), Image (im.MatrixColor("chara/odette/charabody/b_od_sittinghead_lines.png", colorizeBlack)))

image od_sittingNoHead = LiveComposite(
    (174, 415),
    (0, 0), Image (im.MatrixColor("chara/odette/charabody/b_od_sittingnohead_colors.png", colorizeOdetteGrey)),
    (0, 0), Image (im.MatrixColor("chara/odette/charabody/b_od_sittingnohead_lines.png", colorizeBlack)))

image od_armscrossed = LiveComposite(
    (132, 466),
    (0, 0), Image (im.MatrixColor("chara/odette/charabody/b_od_armscrossed_colors.png", colorizeOdetteGrey)),
    (0, 0), Image (im.MatrixColor("chara/odette/charabody/b_od_armscrossed_lines.png", colorizeBlack)))

image da_handsonhips = LiveComposite(
    (233, 572),
    (0, 0), Image (im.MatrixColor("chara/dad/charabody/b_da_handsonhips_colors.png", colorizeDadGrey)),
    (0, 0), Image (im.MatrixColor("chara/dad/charabody/b_da_handsonhips_lines.png", colorizeBlack)))



# The following five images are bg images & persistant props for the sample "kitchen" stage
image bg kitchen = LiveComposite(
    (1920, 776),
    (0, 0), Image (im.MatrixColor("bg/kitchen/kitchen_grey.png", colorizeStageGrey)),
    (0, 0), Image (im.MatrixColor("bg/kitchen/kitchen_lines.png", colorizeStagePropLines)),
    (0, 0), "uiimages/placementgrid.png")

image kitchentable = LiveComposite(
    (660, 323),
    (0, 0), Image (im.MatrixColor("bg/kitchen/table-colors.png", colorizePropGrey)),
    (0, 0), Image (im.MatrixColor("bg/kitchen/table-lines.png", colorizeStagePropLines)))

image kitchenchair1 = LiveComposite(
    (483, 358),
    (0,0), Image (im.MatrixColor("bg/kitchen/chair1-colors.png", colorizePropGrey)),
    (0,0), Image (im.MatrixColor("bg/kitchen/chair1-lines.png", colorizeStagePropLines)))

image kitchenchair1cushion = LiveComposite(
    (483, 358),
    (0,0), Image (im.MatrixColor("bg/kitchen/chair1cushion-colors.png", colorizePropGrey)),
    (0,0), Image (im.MatrixColor("bg/kitchen/chair1cushion-lines.png", colorizeStagePropLines)))

image kitchenchair2 = LiveComposite(
    (819, 330),
    (0,0), Image (im.MatrixColor("bg/kitchen/chair2-colors.png", colorizePropGrey)),
    (0,0), Image (im.MatrixColor("bg/kitchen/chair2-lines.png", colorizeStagePropLines)))


# The following are image declarations for the test [montageSubview] and [visualAidSubview] images:
image va_selfie = LiveComposite(
    (731, 831),
    (0,0), "visualaids/selfie_colors.png",
    (0,0), Image (im.MatrixColor("visualaids/selfie_lines.png", colorizeBlack)))
image va_testimage = "visualaids/va_testimage.png"

image montageverticaltest = "montageimages/montageverticaltest.png"
image montagehorizontaltest = "montageimages/montagehorizontaltest.png"


# (I won't bother declaring all of the images included in the image folder 
# in case I'm doing it wrong for however the visual novel is ultimately implemented.)


label start:

    # Before anything else, we should show the control screen, as described in the design doc under "Reader Interaction"
    
    # After that, we should show [timeChangeSubview] with the time "Monday Evening".
    
    # Then we should have whatever code is necessary to show [middleText] [narration]:

    "This is test text for this super-exciting test visual novel."
    
    "If all is going to plan, you should be reading [[middleText] [[narration], i.e. text centered on the screen."
    
    "At it's longest, text might look like this (pardon the weird text):"
    
    "The blob of atoms that is me would continue The blob of atoms that is me would continue The blob of atoms that is me would continue"
    
    "Also in a perfect world, text will be centered vertically depending on if there is 1, 2, or 3 lines."
    
    "Okay, let's try something else."
    
    "Next let's show [[montageView] with panning images."
     
    # Here we should have whatever code we need to switch to [montageView].
    
    # Then we should show montageverticaltest, panning down over 5 seconds. 
    # In the design doc, section "Showing Images within [visualAidSubview] and [montageSubview]", I made up pseudo code like this:
    # show montageverticaltest at PanDown(5.0)
    
    # After it finishes panning and the reader clicks, next it should show montagehorizontaltest panning to the left over 3 seconds.
    # Again using the pseudo code from "Showing Images within [visualAidSubview] and [montageSubview]":
    # show montagehorizontaltest at panLeft(3.0)
    
    # After all that, insert code to make it return to [middleText] [narration].
    
    "Did the montage images work? If so, great!"
    
    "Next, let's switch to [[stageView], the main view of the game."
    
    # Here we should have whatever code is needed to show [stageView], using the kitchen stage.
    
    # Below is my hacked together background. Ideally the table and chairs, although being in the
    # foreground, would be a part of the kitchen "stage", so I wouldn't always have to show them 
    # seperately every time I went to the kitchen stage. But I guess it's not a big deal either way.
    scene bg kitchen at Position(align=(0.0,0.0))
    show bottombar at Position(xalign=0.0, yanchor=0, ypos=756)
    show kitchentable at Position(xalign=0.0, yanchor=1.0, ypos=721) zorder 140
    show kitchenchair1 at Position(xalign=0.0, yanchor=1.0, ypos=741) zorder 150
    show kitchenchair1cushion at Position(xalign=0.0, yanchor=1.0, ypos=741) zorder 148
    show kitchenchair2 at Position(xalign=0.0, yanchor=1.0, ypos=703) zorder 131
    
    "If everything went to plan, you should be seeing the kitchen now."
    
    "As with all text in [[stageView], text should be [[bottomText]."
    
    "Now let's try to put the Dad character on the stage."
    
    # Here we should have the code to show Dad, with a [3/4thFace], normal expression, with the hands on hips body.
    # To use my pseudo code from the design doc, section "Character Placement Sample":
    # show dad 3/4ths normal handsonhips at stagePos(1150, 15.0)
    # Since stagePos doesn't exist yet and since I don't know how to make a version with a head, I'll just provisionally show a headless version:
    
    show da_handsonhips at Position(anchor=(0.5,1.0), pos=(1150, 741))
    
    "Cool. Now let's put Odette so she's sitting on the chair."

    # Here we should have the code to show od_sittingWithHead in the chair, using stagePos. The pseudo code might look like:
    # show odette sittingWithHead at stagePos(394, 14.9)
    # I'll just put her there temporarily to test:
    
    show od_sittingWithHead at Position(anchor=(0.5,1.0), pos=(394,739)) zorder 149
    
    "We're using a [[charaBody] for her that should have her [[showHead] boolean set to false, so no [[charaHead] will be used."
    
    "Okay, now let's put Dad near the door, flip him around to be facing Odette, and change his head angle to profile."
    
    # Here we should have whatever code we need to make that happen. In the design doc, "Character Placement Sample", I wrote it like this:
    # show flipped dad profile normal handsonhips at stagePos(1700, 15.0)
    # I'm sure it'll need to be different from that, but anyway. I'll just provisionally show an unflipped version at that location:
    
    show da_handsonhips at Position(anchor=(0.5,1.0), pos=(1700, 741))
    
    "Okay, next let's put Dad up next to the fridge. Thanks to [[autoScale], he should shrink, so he won't look huge."
    
    # [autoScale] described in the design doc, under the section "When [onFloor] is true"
    # Pseudo code might look like this:
    # show dad at stagePos(1600, 9.0)
    # I'll just show it with position like before. Unfortunately, there's no [autoScale] yet, so he looks huge in my provisional code, oh well. 
    
    show da_handsonhips at Position(anchor=(0.5,1.0), pos=(1600, 621))
    
    "Okay, now let's switch Odette's body to be one that needs a [[charaHead]. We'll use a head angle of [[profileFace]."
    
    # Pseudo code for that:
    # show odette happy profile sittingNoHead at stagePos(407, 14.9)
    # Again, my provisional show declaration for that, without a head:
    
    hide od_sittingWithHead
    show od_sittingNoHead at Position(anchor=(0.5,1.0), pos=(407,739)) zorder 149
    
    # Ideally, it should automatically hide an old [charaBody] when a new one is shown, 
    # since there should only be one instance of a character on stage at a time.
    
    "Okay. Now let's try out [[stageView][[dialogue]."
    
    # [pseudo code]: show odette irritated
    
    o "Hey! I'm talking over here!"
    
    # [pseudo code]: show dad skeptical
    
    d "Yeah yeah, I hear ya!"
    
    o "Hold on, I'm gonna get up."
    
    # [pseudo code]: show odette front angry armscrossed at stagePos(900, 14.0)
    # And again, my provisional code with creepy headless characters.
    
    hide od_sittingNoHead
    show od_armscrossed at Position(anchor=(0.5,1.0), pos=(900,721)) zorder 140
    
    o "Hmph!"
    
    "Okay, now we've trasitioned back from [[dialogue] to [[narration]." 
    "Hopefully the transition looked good."
    
    "Next let's try switching into [[visualAidSubview] using a circle iris wipe."
    
    # The code to do that should be displayed here. A description of what that should look like can be found in the design doc under:
    # "Default circle iris wipe transitions into [visualAidSubview]"
    # [pseudo code]: show va_selfie
    
    "Okay! Now we should be in [[visualAidSubview], and an image of a silly embarassing selfie should be on screen."
    
    "Let's try swapping in a different visual aid image."
    
    # [pseudo code]: show va_testimage
    
    "Okay, didn't spend as long drawing that one, har har."
    
    "Anyway, let's switch back to the [[stageView]."
    
    # Code to switch back should go here.
    
    "The [[stageChara] should be in the same position as before the switch to [[visualAidSubview], with the same expressions, etc."
    
    "Okay, now let's switch over to [[talkingHeadSubview] and test that out."
    
    # Code to switch over to [talkingHeadSubview], with Odette happy on the left and Dad normal on the right.
    
    o "I'm feeling great!"
    
    # show Dad skeptical
    
    d "Well, I'm glad someone is."
    
    # show odette angry
    
    o "Hey! Don't rain on my parade!"
    
    # show odette irritated
    
    "Here's how [[bottomText] [[narration] should look in [[talkingHeadSubview]."
    
    "The characters should have scooted up automatically."
    
    # show odette happy
    
    o "Hey! We {i}did!{/i} How cool!"
    
    # show odette irritated
    
    o "Wha? Why did we scoot back down?"
    
    # show dad normal
    
    d "Because you started talking, and in [[talkingHeadSubview], dialogue is shown as [[topText]. Duh."
    
    # show odette angry
    
    "Okay, enough of that nonsense. Let's return to [[stageView]."
    
    # Insert code here to have them return to [stageView].
    
    "Okay, let's test one last thing and then we'll call it a day."
    
    "Let's switch to nighttime and see if [[contextualBlack] and [[accentColor] can be changed dynamically."
    
    # Insert code to go to [timeChangeSubview].
    # Switch time to "Monday Night", with [contextualBlack] changing to Color((56,53,97)), and [accentColor] changing to Color((74,84,166))
    # Next, after the reader clicks, have the scene return to the kitchen, which is now empty.
    
    "Well? Did it work? Does it look like night in the kitchen now?"
    
    "Okay, that should do it for this test. Hope you enjoyed it!"
    
    "Buh-bye!"
    
    return
